@@ -39,7 +39,7 @@ impl CommandTrait for Evaluator {
 				})
 				.collect();
 
-			let table = Table::new(table_entries).with(Style::pseudo_clean());
+			let table = Table::new(table_entries).with(Style::PSEUDO_CLEAN);
 			println!("{}", table.to_string());
 		} else {
 			println!("<EMPTY ARCHIVE> @ {}", archive_path);
